require 'thor'
require 'colorize'
require 'fileutils'
require 'date'
require 'json'

module Til
  class Cli < Thor
    map "-v" => :version, "-V" => :version

    desc "version", "Show TIL version"
    def version
      require "til/version.rb"
      say "til_cli #{Til::VERSION}"
    end

    desc "config", "Generate a settings file if one doesn't already exist."
    def config
      Til.config_settings_file_and_notes_repo
    end

    desc "github", "If your notes have a remote repository on Github, open it."
    def github
      Til.open_github_page_for_repo
    end

    desc "edit [SEARCH TERM]", "Edit file that matches search for [SEARCH TERM]."
    long_desc "`--last` flag"
    option :last, type: :boolean
    def edit(keyword="")
      Til.edit_file(keyword, options)
    end

    desc "new SUBJECT \"TITLE\"", "Generate a new note with TITLE about SUBJECT. TITLE should be quoted and shell metacharacters escaped."
    def new(subject, title)
      Til.new_note(subject, title)
    end

    desc "ls [SUBJECT]", "List all notes [on SUBJECT]"
    option :subjects, type: :boolean
    def ls(subject = nil)
      if options[:subjects]
        Til.list_subjects
      elsif subject
        Til.list_notes_in(subject)
      else
        Til.list_all_notes
      end
    end

    desc "pwd", "Print the path of your TIL working directory"
    def pwd
      Til.print_working_directory
    end

    desc "last [QUANTITY]", "Print [QUANTITY] most recent note[s]"
    def last(quantity=1)
      Til.print_most_recent_note quantity.to_i
    end

    desc "cat [SUBJECT]", "Print all notes [on SUBJECT]"
    def cat(subject=nil)
      if subject
        Til.print_all_notes_in(subject)
      else
        Til.print_all_notes
      end
    end

    desc "git COMMAND", "Run Git COMMAND in TIL directory"
    def git(*args)
      Til.run_git_command(*args)
    end

    desc "grep COMMAND", "Run grep COMMAND in TIL directory"
    def grep(*args)
      Til.run_grep_command(*args)
    end

    desc "ag COMMAND", "Run Silver Searcher COMMAND in TIL directory"
    def ag(*args)
      Til.run_ag_command(*args)
    end

    desc "rm [SEARCH TERM]", "Remove a file matching the search term. Prompts for confirmation."
    def rm(keyword)
      Til.remove_file(keyword)
    end
  end
end
